@@ -1,4 +1,4 @@
-"""
+'''
 # aws-kinesisfirehose-s3-and-kinesisanalytics module
 
 <!--BEGIN STABILITY BANNER-->---
@@ -128,7 +128,7 @@ Out of the box implementation of the Construct without any override will set the
 
 
 © Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -154,9 +154,9 @@ class KinesisFirehoseToAnalyticsAndS3(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-kinesisfirehose-s3-and-kinesisanalytics.KinesisFirehoseToAnalyticsAndS3",
 ):
-    """
+    '''
     :summary: The KinesisFirehoseToAnalyticsAndS3 class.
-    """
+    '''
 
     def __init__(
         self,
@@ -169,7 +169,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         kinesis_firehose_props: typing.Any = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """
+        '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
@@ -181,7 +181,7 @@ class KinesisFirehoseToAnalyticsAndS3(
         :access: public
         :since: 0.8.0
         :summary: Constructs a new instance of the KinesisFirehoseToAnalyticsAndS3 class.
-        """
+        '''
         props = KinesisFirehoseToAnalyticsAndS3Props(
             bucket_props=bucket_props,
             existing_bucket_obj=existing_bucket_obj,
@@ -244,14 +244,14 @@ class KinesisFirehoseToAnalyticsAndS3Props:
         kinesis_firehose_props: typing.Any = None,
         log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
     ) -> None:
-        """The properties for the KinesisFirehoseToAnalyticsAndS3 class.
+        '''The properties for the KinesisFirehoseToAnalyticsAndS3 class.
 
         :param bucket_props: User provided props to override the default props for the S3 Bucket. Default: - Default props are used
         :param existing_bucket_obj: Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. Default: - None
         :param kinesis_analytics_props: Optional user-provided props to override the default props for the Kinesis Analytics application. Default: - Default props are used.
         :param kinesis_firehose_props: Optional user-provided props to override the default props for the Kinesis Firehose delivery stream. Default: - Default props are used.
         :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
-        """
+        '''
         if isinstance(bucket_props, dict):
             bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_analytics_props, dict):
@@ -272,19 +272,19 @@ class KinesisFirehoseToAnalyticsAndS3Props:
 
     @builtins.property
     def bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
-        """User provided props to override the default props for the S3 Bucket.
+        '''User provided props to override the default props for the S3 Bucket.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("bucket_props")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
     @builtins.property
     def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
-        """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
+        '''Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         :default: - None
-        """
+        '''
         result = self._values.get("existing_bucket_obj")
         return typing.cast(typing.Optional[aws_cdk.aws_s3.IBucket], result)
 
@@ -292,28 +292,28 @@ class KinesisFirehoseToAnalyticsAndS3Props:
     def kinesis_analytics_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps]:
-        """Optional user-provided props to override the default props for the Kinesis Analytics application.
+        '''Optional user-provided props to override the default props for the Kinesis Analytics application.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("kinesis_analytics_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kinesisanalytics.CfnApplicationProps], result)
 
     @builtins.property
     def kinesis_firehose_props(self) -> typing.Any:
-        """Optional user-provided props to override the default props for the Kinesis Firehose delivery stream.
+        '''Optional user-provided props to override the default props for the Kinesis Firehose delivery stream.
 
         :default: - Default props are used.
-        """
+        '''
         result = self._values.get("kinesis_firehose_props")
         return typing.cast(typing.Any, result)
 
     @builtins.property
     def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
-        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+        '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
-        """
+        '''
         result = self._values.get("log_group_props")
         return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
 
